@@ -46,7 +46,7 @@ class Item:
 
 class IronCache:
     NAME = "iron_cache_python"
-    VERSION = "0.2.0"
+    VERSION = "0.3.0"
     client = None
     name = None
 
@@ -118,7 +118,7 @@ class IronCache:
                 (int, long)):
             value = json.dumps(value)
 
-        options["body"] = value
+        options["value"] = value
         body = json.dumps(options)
 
         cache = urllib.quote_plus(cache)
